TRAMPknowns object from a
TRAMPsamples object. Samples are considered to be
build.knowns(d, min.ratio=3, min.comb=NA, restrict=FALSE, ...)TRAMPsamples object, containing samples from which
to build the knowns database.d$info$species is
non-blank? (These are assumed to come from samples of a known
species. However, it is not guaranteed that all samples with data for
species will become knowns; if tTRAMPknowns
(e.g. cluster.pars, file.pat and any additional
objects).TRAMPknowns object. It will generally be neccessary to
edit this object; see read.TRAMPknowns for details on
how to write, edit, and read back a modified object.min.ratio, then that combination is accepted. If the
sample has at least min.comb valid enzyme/primer combinations,
then that sample is included in the knowns database. If
min.comb is NA (the default), then every
enzyme/primer combination present in the data is required.data(demo.samples)
demo.knowns.auto <- build.knowns(demo.samples, min.comb=4)
plot(demo.knowns.auto, cex=.75)Run the code above in your browser using DataLab