demo.knowns: Demonstration Knowns Database
Description
A knowns database, for demonstrating the TRAMPR package.
This is a subset of a full knowns database, and not intended to
represent any real data set, and should not be assumed to be
accurate.
The data are stored as a TRAMPknowns object. Columns in
the info and data components are described on the
TRAMPknowns page.Licence
This data set is provided under a Creative Commons
Attribution-NonCommercial-NoDerivs 2.5 licence. Please see
http://creativecommons.org/licenses/by-nc-nd/2.5/ for details.